# Developer documentation

```{include} ../../CONTRIBUTING.md
```

## Table of contents

```{toctree}
---
maxdepth: 2
---

getting-started
coding-conventions
dependency-management
architecture-and-design/index
```
